============
wsp-jacquard
============

``wsp-jacquard`` is a collection of functions and tools for Python to handle JSON-based configurations for models.

Historically, a Jacquard machine is a programmable loom controlled by a chain of cards (https://en.wikipedia.org/wiki/Jacquard_machine); the term "jacquard" refers to the card (or set of cards) used to configure the machine. The `jacquard` library is designed to facilitate application of models, where the a model's configuration (locations of data, options, parameters) are stored in a human-readable JSON file.

Installation
------------

Jacquard can be installed with conda by running:

.. code-block:: bash

   conda install -c wsp_sap wsp-jacquard

.. toctree::
   :maxdepth: 3
   :caption: Contents

   overview/index
   api_reference/index
